@@ -13,6 +13,11 @@ When running, you can communicate with it via a RESTful web interface, as descri
 
 L<http://agraph.franz.com/support/documentation/3.2/new-http-server.html>
 
+and
+L<http://www.franz.com/agraph/support/documentation/v4/http-protocol.html>
+
+respectively.
+
 This package offers a client implementation of that protocol. With it you can either use
 a rather orthodox style (L<RDF::AllegroGraph::Server>) or a quick-n-easy approach (L<RDF::AllegroGraph::Easy>).
 
@@ -24,9 +29,8 @@ B<NOTE>: This is still exploratory. See the TODO.
 
 =item I<I receive a protocol error: 400 Bad Request from the server>
 
-4xx responses normally mean that the client is to blame, but AG seems
-to send such responses also in the case it has permission problems on
-the server. Maybe check that first.
+4xx responses normally mean that the client is to blame, but AG seems to send such responses also in
+the case it has permission problems on the server. Maybe check that first.
 
 =back
 
@@ -36,17 +40,19 @@ Robert Barta, C<< <rho at devc.at> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 20(0[9]|10) Robert Barta, all rights reserved.
+Copyright 20(0[9]|10|11) Robert Barta, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl
 itself.
 
+Test data courtesy of Franz Inc.
+
 =head1 SEE ALSO
 
 L<RDF::AllegroGraph::Server>, L<RDF::AllegroGraph::Easy>
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 1;
